@@ -10,6 +10,8 @@ from io import TextIOWrapper
 
 from datetime import datetime, time, timedelta
 
+from elasticsearch_dsl.utils import AttrDict, AttrList
+
 from django.utils.timezone import now, utc
 from django.utils.module_loading import import_string
 from django.core.serializers.json import DjangoJSONEncoder
@@ -28,7 +30,7 @@ from security.backends.writer import BaseBackendWriter
 
 from .models import (
     CeleryTaskRunLog, CeleryTaskInvocationLog, get_key_from_content_type_object_id_and_model_db, get_response_state,
-    get_log_model_from_logger_name, get_object_triple_from_key, logger_name_to_log_model, get_index_name
+    get_log_model_from_logger_name, get_object_triple_from_key, logger_name_to_log_model, get_index_name, refresh_model
 )
 
 
@@ -65,12 +67,16 @@ class BaseElasticsearchDataWriter:
         ]
 
     def _get_index_data(self, index):
-        return {
-            field_name: (
-                getattr(index, field_name).to_dict() if description['type'] == 'object' else getattr(index, field_name)
-            )
-            for field_name, description in index._doc_type.mapping.properties.to_dict()['properties'].items()
-        }
+        index_data = {}
+        for field_name in index._doc_type.mapping.properties.to_dict()['properties'].keys():
+            value = getattr(index, field_name)
+            if isinstance(value, AttrList):
+                value = value._l_
+            elif isinstance(value, AttrDict):
+                value = value.to_dict()
+
+            index_data[field_name] = value
+        return index_data
 
     def _update_data(self, data):
         data = dict(data)
@@ -300,7 +306,7 @@ class ElasticsearchBackendWriter(BaseBackendWriter):
             logger, is_last=True, state=CeleryTaskRunLogState.SUCCEEDED
         )
 
-        CeleryTaskInvocationLog._index.refresh()
+        refresh_model(CeleryTaskInvocationLog)
         celery_task_invocations_qs = CeleryTaskInvocationLog.search().filter(
             'term', celery_task_id=logger.data['celery_task_id']
         ).query(
@@ -319,7 +325,7 @@ class ElasticsearchBackendWriter(BaseBackendWriter):
         self.get_data_writer().create_or_update_index_from_logger(
             logger, is_last=True, state=CeleryTaskRunLogState.FAILED
         )
-        CeleryTaskInvocationLog._index.refresh()
+        refresh_model(CeleryTaskInvocationLog)
         celery_task_invocations_qs = CeleryTaskInvocationLog.search().filter(
             'term', celery_task_id=logger.data['celery_task_id']
         ).query(
